summaryrefslogtreecommitdiffstats
path: root/chrome/browser/automation/automation_provider.h
diff options
context:
space:
mode:
authorjohnnyg@chromium.org <johnnyg@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-11-11 21:48:18 +0000
committerjohnnyg@chromium.org <johnnyg@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-11-11 21:48:18 +0000
commit816633af02b2e7e2c5be5f760db60dee502f326b (patch)
tree461fba4349a961e90606c48bceeeafc46bea66f9 /chrome/browser/automation/automation_provider.h
parent6a3e3081b35adfdc055a32d7d7d2a91b5e31d09c (diff)
downloadchromium_src-816633af02b2e7e2c5be5f760db60dee502f326b.zip
chromium_src-816633af02b2e7e2c5be5f760db60dee502f326b.tar.gz
chromium_src-816633af02b2e7e2c5be5f760db60dee502f326b.tar.bz2
Rename unused "SSL" related automation methods to be generic, since that's what these methods actually do, and so I can repurpose them for a different info-bar test.
BUG=none TEST=none Review URL: http://codereview.chromium.org/385029 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@31718 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/automation/automation_provider.h')
-rw-r--r--chrome/browser/automation/automation_provider.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/chrome/browser/automation/automation_provider.h b/chrome/browser/automation/automation_provider.h
index 66e7de8..5b5ac29 100644
--- a/chrome/browser/automation/automation_provider.h
+++ b/chrome/browser/automation/automation_provider.h
@@ -413,15 +413,15 @@ class AutomationProvider : public base::RefCounted<AutomationProvider>,
const std::string& origin,
const std::string& target);
- // Retrieves the number of SSL related info-bars currently showing in |count|.
- void GetSSLInfoBarCount(int handle, int* count);
+ // Retrieves the number of info-bars currently showing in |count|.
+ void GetInfoBarCount(int handle, int* count);
- // Causes a click on the link of the info-bar at |info_bar_index|. If
- // |wait_for_navigation| is true, it sends the reply after a navigation has
+ // Causes a click on the "accept" button of the info-bar at |info_bar_index|.
+ // If |wait_for_navigation| is true, it sends the reply after a navigation has
// occurred.
- void ClickSSLInfoBarLink(int handle, int info_bar_index,
- bool wait_for_navigation,
- IPC::Message* reply_message);
+ void ClickInfoBarAccept(int handle, int info_bar_index,
+ bool wait_for_navigation,
+ IPC::Message* reply_message);
// Retrieves the last time a navigation occurred for the tab.
void GetLastNavigationTime(int handle, int64* last_navigation_time);